
--[[

name:   CountDown
vers:   1.0.0
desc:   A simple counter that counts down to 0 and runs a function on completion.
auth:   by Cliff Earl, Antix Software
date:   August 2016
legal:  Distribute freely but please leave my credits intact.

--]]

CountDown = Core.class(Sprite)

function CountDown:init(options) -- Setup counter

  local props = { -- Default options
    x           = 16,
    y           = 16,
	scale       = 1,
    alpha       = 1,
	color       = 0x000000,
    font        = nil,
    duration    = 10,
    onComplete  = nil,
  }
	
  if options then
    for key, value in pairs(options) do
      props[key]= value
    end
  end

  self. countingDown = false
  self.counter = 0

  local text = TextField.new(props.font, props.duration) -- Create text
  text:setTextColor(props.color)
  self:addChild(text)

  self:setPosition(props.x, props.y) -- Position, etc
  self:setScale(props.scale)
  self:setAlpha(props.alpha)

  self.props = props
  self.text = text
end

function CountDown:start() -- Start the counter
  local props = self.props
  self.counter = props.duration + 1
  self:show(true)
  self.countingDown = true
end

function CountDown:setDuration(duration) -- Set duration of counter
  local props = self.props
  props.duration = duration
end

function CountDown:show(state) -- Show or hide counter
  self:setVisible(state)
end

function CountDown:updateText() -- Update the counter text
  local text = self.text
  local counter= math.floor(self.counter)
  text:setText(counter)
end

function CountDown:update(dt) -- Call this every frame

  if not self.countingDown then return end -- If not running then just exit

  local counter = self.counter - dt -- Decrement counter
  
  self:updateText() -- Update the text
  
  if counter <= 1 then -- Has counter run down?

    self.countingDown = false -- stop any further counting down
    self:show(false) -- Hide ourselves
    if self.props.onComplete then
      self.props.onComplete() -- Call function when the count down reaches 0
    end

  end
  self.counter = counter
  
end
